async_trait

Attribute Macro async_trait 

#[async_trait]
The #[async_trait] attribute, re-exported so an out-of-crate implementor of RequestPolicy (or http::auth::HttpAuthProvider) does not have to add an async-trait dependency of its own — and, more importantly, cannot end up on a DIFFERENT version of it than the trait was declared with, which produces a signature-mismatch error that reads as a lifetime bug.