#[non_exhaustive]pub enum RequestPhase {
Execute,
Validate,
}Expand description
Whether an OutboundRequest is about to be sent or is only being previewed,
see OutboundRequest::phase.
#[non_exhaustive]: a policy must have a wildcard arm, so a later phase is
not a breaking change.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Execute
The request is about to be sent. What every request was before validation previews existed, and the default.
Validate
A dry-run preview made by validate_code. Nothing is sent.