pub struct OrgSecretsManagerProvider { /* private fields */ }Expand description
AWS Secrets Manager provider for org-level shared secrets.
This provider handles hierarchical secrets where multiple servers share a single secret with the structure:
{
"london-tube": {
"TFL_APP_KEY": "xxx"
},
"lichess": {
"LICHESS_TOKEN": "yyy"
}
}The provider extracts secrets only for the specific server_id.
Implementations