pub struct SecretsProviderChain { /* private fields */ }Expand description
Chain multiple providers, trying each in order until one succeeds.
Implementations
Sourceimpl SecretsProviderChain
impl SecretsProviderChain
Sourcepub fn new(providers: Vec<Arc<dyn SecretsProvider>>) -> Self
pub fn new(providers: Vec<Arc<dyn SecretsProvider>>) -> Self
Construct a chain from an ordered list of providers.